tiled.client.xarray.DaskDatasetClient
=====================================

.. currentmodule:: tiled.client.xarray

.. autoclass:: DaskDatasetClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DaskDatasetClient.__init__
      ~DaskDatasetClient.discover_clients_from_entrypoints
      ~DaskDatasetClient.distinct
      ~DaskDatasetClient.download
      ~DaskDatasetClient.export
      ~DaskDatasetClient.get
      ~DaskDatasetClient.items
      ~DaskDatasetClient.keys
      ~DaskDatasetClient.login
      ~DaskDatasetClient.logout
      ~DaskDatasetClient.new
      ~DaskDatasetClient.new_variation
      ~DaskDatasetClient.read
      ~DaskDatasetClient.refresh
      ~DaskDatasetClient.search
      ~DaskDatasetClient.sort
      ~DaskDatasetClient.update_metadata
      ~DaskDatasetClient.values
      ~DaskDatasetClient.write_array
      ~DaskDatasetClient.write_dataframe
      ~DaskDatasetClient.write_sparse
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DaskDatasetClient.STRUCTURE_CLIENTS_FROM_ENTRYPOINTS
      ~DaskDatasetClient.context
      ~DaskDatasetClient.formats
      ~DaskDatasetClient.item
      ~DaskDatasetClient.items_indexer
      ~DaskDatasetClient.keys_indexer
      ~DaskDatasetClient.metadata
      ~DaskDatasetClient.metadata_revisions
      ~DaskDatasetClient.offline
      ~DaskDatasetClient.references
      ~DaskDatasetClient.sorting
      ~DaskDatasetClient.specs
      ~DaskDatasetClient.uri
      ~DaskDatasetClient.values_indexer
   
   